# mutual information

This is a python package that calculates the synergy between two or more variables for one response.


## installation

install from pypi:
```bash
pip install mutual-information
```

install from source (dev mode):
```bash
pip install -e .[dev]
```

## usage

@TODO: will be added